@@ -50,6 +50,7 @@ let Aardvark = exports.Aardvark =
 		this.browser.addEventListener("DOMMouseScroll", this.onMouseScroll, true);
 		this.browser.addEventListener("keypress", this.onKeyPress, true);
 		this.browser.addEventListener("mousemove", this.onMouseMove, true);
+		this.browser.addEventListener("select", this.quit, false);
 		this.browser.contentWindow.addEventListener("pagehide", this.onPageHide, true);
 	
 		this.browser.contentWindow.focus();
@@ -381,19 +382,7 @@ let Aardvark = exports.Aardvark =
 
 	getWindowSize: function(wnd)
 	{
-		// Cannot use wnd.innerWidth/Height because they won't account for scrollbars
-		let doc = wnd.document;
-		let wndWidth = doc.documentElement.clientWidth;
-		let wndHeight = doc.documentElement.clientHeight;
-		if (doc.compatMode == "BackCompat") // clientHeight will be bogus in quirks mode
-			wndHeight = Math.max(doc.documentElement.offsetHeight, doc.body.offsetHeight) - wnd.scrollMaxY - 1;
-
-		// Failsafe: document size will be meaningless if all elements use absolute positioning
-		if (wndWidth <= 0)
-			wndWidth = wnd.innerWidth;
-		if (wndHeight <= 0)
-			wndHeight = wnd.innerHeight;
-		return [wndWidth, wndHeight];
+		return [wnd.innerWidth, wnd.innerHeight];
 	},
 
 	getElementPosition: function(element)
@@ -542,6 +531,7 @@ let Aardvark = exports.Aardvark =
 		this.browser.removeEventListener("DOMMouseScroll", this.onMouseScroll, true);
 		this.browser.removeEventListener("keypress", this.onKeyPress, true);
 		this.browser.removeEventListener("mousemove", this.onMouseMove, true);
+		this.browser.removeEventListener("select", this.quit, false);
 		this.browser.contentWindow.removeEventListener("pagehide", this.onPageHide, true);
 
 		this.anchorElem = null;
@@ -740,5 +730,5 @@ let Aardvark = exports.Aardvark =
 
 // Makes sure event handlers like Aardvark.onKeyPress always have the correct
 // this pointer set.
-for each (let method in ["onMouseClick", "onMouseScroll", "onKeyPress", "onPageHide", "onMouseMove", "onAfterPaint"])
+for each (let method in ["onMouseClick", "onMouseScroll", "onKeyPress", "onPageHide", "onMouseMove", "onAfterPaint", "quit"])
 	Aardvark[method] = Aardvark[method].bind(Aardvark);
